==> camel-k-model-v1-6.3.0-sources.jar: io/fabric8/camelk/v1/CamelSchemeFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CamelSchemeFluentImpl<A extends CamelSchemeFluent<A>> extends BaseFluent<A> implements CamelSchemeFluent<A>{
  public CamelSchemeFluentImpl() {
  }
  public CamelSchemeFluentImpl(CamelScheme instance) {
    this.withConsumer(instance.getConsumer()); 
    this.withHttp(instance.getHttp()); 
    this.withId(instance.getId()); 
    this.withPassive(instance.getPassive()); 
    this.withProducer(instance.getProducer()); 
  }
  private CamelSchemeScopeBuilder consumer;
  private Boolean http;
  private String id;
  private Boolean passive;
  private CamelSchemeScopeBuilder producer;
  
  /**
   * This method has been deprecated, please use method buildConsumer instead.
   * @return The buildable object.
   */
  @Deprecated
  public CamelSchemeScope getConsumer() {
    return this.consumer!=null ?this.consumer.build():null;
  }
  public CamelSchemeScope buildConsumer() {
    return this.consumer!=null ?this.consumer.build():null;
  }
  public A withConsumer(CamelSchemeScope consumer) {
    _visitables.get("consumer").remove(this.consumer);
    if (consumer!=null){ this.consumer= new CamelSchemeScopeBuilder(consumer); _visitables.get("consumer").add(this.consumer);} else { this.consumer = null; _visitables.get("consumer").remove(this.consumer); } return (A) this;
  }
  public Boolean hasConsumer() {
    return this.consumer != null;
  }
  public CamelSchemeFluent.ConsumerNested<A> withNewConsumer() {
    return new CamelSchemeFluentImpl.ConsumerNestedImpl();
  }
  public CamelSchemeFluent.ConsumerNested<A> withNewConsumerLike(CamelSchemeScope item) {
    return new CamelSchemeFluentImpl.ConsumerNestedImpl(item);
  }
  public CamelSchemeFluent.ConsumerNested<A> editConsumer() {
    return withNewConsumerLike(getConsumer());
  }
  public CamelSchemeFluent.ConsumerNested<A> editOrNewConsumer() {
    return withNewConsumerLike(getConsumer() != null ? getConsumer(): new CamelSchemeScopeBuilder().build());
  }
  public CamelSchemeFluent.ConsumerNested<A> editOrNewConsumerLike(CamelSchemeScope item) {
    return withNewConsumerLike(getConsumer() != null ? getConsumer(): item);
  }
  public Boolean getHttp() {
    return this.http;
  }
  public A withHttp(Boolean http) {
    this.http=http; return (A) this;
  }
  public Boolean hasHttp() {
    return this.http != null;
  }
  public String getId() {
    return this.id;
  }
  public A withId(String id) {
    this.id=id; return (A) this;
  }
  public Boolean hasId() {
    return this.id != null;
  }
  public Boolean getPassive() {
    return this.passive;
  }
  public A withPassive(Boolean passive) {
    this.passive=passive; return (A) this;
  }
  public Boolean hasPassive() {
    return this.passive != null;
  }
  
  /**
   * This method has been deprecated, please use method buildProducer instead.
   * @return The buildable object.
   */
  @Deprecated
  public CamelSchemeScope getProducer() {
    return this.producer!=null ?this.producer.build():null;
  }
  public CamelSchemeScope buildProducer() {
    return this.producer!=null ?this.producer.build():null;
  }
  public A withProducer(CamelSchemeScope producer) {
    _visitables.get("producer").remove(this.producer);
    if (producer!=null){ this.producer= new CamelSchemeScopeBuilder(producer); _visitables.get("producer").add(this.producer);} else { this.producer = null; _visitables.get("producer").remove(this.producer); } return (A) this;
  }
  public Boolean hasProducer() {
    return this.producer != null;
  }
  public CamelSchemeFluent.ProducerNested<A> withNewProducer() {
    return new CamelSchemeFluentImpl.ProducerNestedImpl();
  }
  public CamelSchemeFluent.ProducerNested<A> withNewProducerLike(CamelSchemeScope item) {
    return new CamelSchemeFluentImpl.ProducerNestedImpl(item);
  }
  public CamelSchemeFluent.ProducerNested<A> editProducer() {
    return withNewProducerLike(getProducer());
  }
  public CamelSchemeFluent.ProducerNested<A> editOrNewProducer() {
    return withNewProducerLike(getProducer() != null ? getProducer(): new CamelSchemeScopeBuilder().build());
  }
  public CamelSchemeFluent.ProducerNested<A> editOrNewProducerLike(CamelSchemeScope item) {
    return withNewProducerLike(getProducer() != null ? getProducer(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CamelSchemeFluentImpl that = (CamelSchemeFluentImpl) o;
    if (consumer != null ? !consumer.equals(that.consumer) :that.consumer != null) return false;
    if (http != null ? !http.equals(that.http) :that.http != null) return false;
    if (id != null ? !id.equals(that.id) :that.id != null) return false;
    if (passive != null ? !passive.equals(that.passive) :that.passive != null) return false;
    if (producer != null ? !producer.equals(that.producer) :that.producer != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(consumer,  http,  id,  passive,  producer,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (consumer != null) { sb.append("consumer:"); sb.append(consumer + ","); }
    if (http != null) { sb.append("http:"); sb.append(http + ","); }
    if (id != null) { sb.append("id:"); sb.append(id + ","); }
    if (passive != null) { sb.append("passive:"); sb.append(passive + ","); }
    if (producer != null) { sb.append("producer:"); sb.append(producer); }
    sb.append("}");
    return sb.toString();
  }
  public A withHttp() {
    return withHttp(true);
  }
  public A withPassive() {
    return withPassive(true);
  }
  class ConsumerNestedImpl<N> extends CamelSchemeScopeFluentImpl<CamelSchemeFluent.ConsumerNested<N>> implements CamelSchemeFluent.ConsumerNested<N>,Nested<N>{
    ConsumerNestedImpl(CamelSchemeScope item) {
      this.builder = new CamelSchemeScopeBuilder(this, item);
    }
    ConsumerNestedImpl() {
      this.builder = new CamelSchemeScopeBuilder(this);
    }
    CamelSchemeScopeBuilder builder;
    public N and() {
      return (N) CamelSchemeFluentImpl.this.withConsumer(builder.build());
    }
    public N endConsumer() {
      return and();
    }
    
  }
  class ProducerNestedImpl<N> extends CamelSchemeScopeFluentImpl<CamelSchemeFluent.ProducerNested<N>> implements CamelSchemeFluent.ProducerNested<N>,Nested<N>{
    ProducerNestedImpl(CamelSchemeScope item) {
      this.builder = new CamelSchemeScopeBuilder(this, item);
    }
    ProducerNestedImpl() {
      this.builder = new CamelSchemeScopeBuilder(this);
    }
    CamelSchemeScopeBuilder builder;
    public N and() {
      return (N) CamelSchemeFluentImpl.this.withProducer(builder.build());
    }
    public N endProducer() {
      return and();
    }
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/CamelSchemeFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CamelSchemeFluentImpl<A extends CamelSchemeFluent<A>> extends BaseFluent<A> implements CamelSchemeFluent<A>{
  public CamelSchemeFluentImpl() {
  }
  public CamelSchemeFluentImpl(CamelScheme instance) {
    if (instance != null) {
      this.withConsumer(instance.getConsumer());
      this.withHttp(instance.getHttp());
      this.withId(instance.getId());
      this.withPassive(instance.getPassive());
      this.withProducer(instance.getProducer());
    }
  }
  private CamelSchemeScopeBuilder consumer;
  private Boolean http;
  private String id;
  private Boolean passive;
  private CamelSchemeScopeBuilder producer;
  
  /**
   * This method has been deprecated, please use method buildConsumer instead.
   * @return The buildable object.
   */
  @Deprecated
  public CamelSchemeScope getConsumer() {
    return this.consumer!=null ?this.consumer.build():null;
  }
  public CamelSchemeScope buildConsumer() {
    return this.consumer!=null ?this.consumer.build():null;
  }
  public A withConsumer(CamelSchemeScope consumer) {
    _visitables.get("consumer").remove(this.consumer);
    if (consumer!=null){ this.consumer= new CamelSchemeScopeBuilder(consumer); _visitables.get("consumer").add(this.consumer);} else { this.consumer = null; _visitables.get("consumer").remove(this.consumer); } return (A) this;
  }
  public Boolean hasConsumer() {
    return this.consumer != null;
  }
  public CamelSchemeFluentImpl.ConsumerNested<A> withNewConsumer() {
    return new CamelSchemeFluentImpl.ConsumerNestedImpl();
  }
  public CamelSchemeFluentImpl.ConsumerNested<A> withNewConsumerLike(CamelSchemeScope item) {
    return new CamelSchemeFluentImpl.ConsumerNestedImpl(item);
  }
  public CamelSchemeFluentImpl.ConsumerNested<A> editConsumer() {
    return withNewConsumerLike(getConsumer());
  }
  public CamelSchemeFluentImpl.ConsumerNested<A> editOrNewConsumer() {
    return withNewConsumerLike(getConsumer() != null ? getConsumer(): new CamelSchemeScopeBuilder().build());
  }
  public CamelSchemeFluentImpl.ConsumerNested<A> editOrNewConsumerLike(CamelSchemeScope item) {
    return withNewConsumerLike(getConsumer() != null ? getConsumer(): item);
  }
  public Boolean getHttp() {
    return this.http;
  }
  public A withHttp(Boolean http) {
    this.http=http; return (A) this;
  }
  public Boolean hasHttp() {
    return this.http != null;
  }
  public String getId() {
    return this.id;
  }
  public A withId(String id) {
    this.id=id; return (A) this;
  }
  public Boolean hasId() {
    return this.id != null;
  }
  public Boolean getPassive() {
    return this.passive;
  }
  public A withPassive(Boolean passive) {
    this.passive=passive; return (A) this;
  }
  public Boolean hasPassive() {
    return this.passive != null;
  }
  
  /**
   * This method has been deprecated, please use method buildProducer instead.
   * @return The buildable object.
   */
  @Deprecated
  public CamelSchemeScope getProducer() {
    return this.producer!=null ?this.producer.build():null;
  }
  public CamelSchemeScope buildProducer() {
    return this.producer!=null ?this.producer.build():null;
  }
  public A withProducer(CamelSchemeScope producer) {
    _visitables.get("producer").remove(this.producer);
    if (producer!=null){ this.producer= new CamelSchemeScopeBuilder(producer); _visitables.get("producer").add(this.producer);} else { this.producer = null; _visitables.get("producer").remove(this.producer); } return (A) this;
  }
  public Boolean hasProducer() {
    return this.producer != null;
  }
  public CamelSchemeFluentImpl.ProducerNested<A> withNewProducer() {
    return new CamelSchemeFluentImpl.ProducerNestedImpl();
  }
  public CamelSchemeFluentImpl.ProducerNested<A> withNewProducerLike(CamelSchemeScope item) {
    return new CamelSchemeFluentImpl.ProducerNestedImpl(item);
  }
  public CamelSchemeFluentImpl.ProducerNested<A> editProducer() {
    return withNewProducerLike(getProducer());
  }
  public CamelSchemeFluentImpl.ProducerNested<A> editOrNewProducer() {
    return withNewProducerLike(getProducer() != null ? getProducer(): new CamelSchemeScopeBuilder().build());
  }
  public CamelSchemeFluentImpl.ProducerNested<A> editOrNewProducerLike(CamelSchemeScope item) {
    return withNewProducerLike(getProducer() != null ? getProducer(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CamelSchemeFluentImpl that = (CamelSchemeFluentImpl) o;
    if (!java.util.Objects.equals(consumer, that.consumer)) return false;

    if (!java.util.Objects.equals(http, that.http)) return false;

    if (!java.util.Objects.equals(id, that.id)) return false;

    if (!java.util.Objects.equals(passive, that.passive)) return false;

    if (!java.util.Objects.equals(producer, that.producer)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(consumer,  http,  id,  passive,  producer,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (consumer != null) { sb.append("consumer:"); sb.append(consumer + ","); }
    if (http != null) { sb.append("http:"); sb.append(http + ","); }
    if (id != null) { sb.append("id:"); sb.append(id + ","); }
    if (passive != null) { sb.append("passive:"); sb.append(passive + ","); }
    if (producer != null) { sb.append("producer:"); sb.append(producer); }
    sb.append("}");
    return sb.toString();
  }
  public A withHttp() {
    return withHttp(true);
  }
  public A withPassive() {
    return withPassive(true);
  }
  class ConsumerNestedImpl<N> extends CamelSchemeScopeFluentImpl<CamelSchemeFluentImpl.ConsumerNested<N>> implements CamelSchemeFluentImpl.ConsumerNested<N>,Nested<N>{
    ConsumerNestedImpl(CamelSchemeScope item) {
      this.builder = new CamelSchemeScopeBuilder(this, item);
    }
    ConsumerNestedImpl() {
      this.builder = new CamelSchemeScopeBuilder(this);
    }
    CamelSchemeScopeBuilder builder;
    public N and() {
      return (N) CamelSchemeFluentImpl.this.withConsumer(builder.build());
    }
    public N endConsumer() {
      return and();
    }
    
  }
  class ProducerNestedImpl<N> extends CamelSchemeScopeFluentImpl<CamelSchemeFluentImpl.ProducerNested<N>> implements CamelSchemeFluentImpl.ProducerNested<N>,Nested<N>{
    ProducerNestedImpl(CamelSchemeScope item) {
      this.builder = new CamelSchemeScopeBuilder(this, item);
    }
    ProducerNestedImpl() {
      this.builder = new CamelSchemeScopeBuilder(this);
    }
    CamelSchemeScopeBuilder builder;
    public N and() {
      return (N) CamelSchemeFluentImpl.this.withProducer(builder.build());
    }
    public N endProducer() {
      return and();
    }
    
  }
  
}
